/*
 * Automatically generated by SheenBidiGenerator tool.
 * DO NOT EDIT!!
 *
 * REQUIRED MEMORY: 10304+(3935*2)+(897*2) = 19968 Bytes
 */

#include "ScriptLookup.h"

#define Adlm     SBScriptADLM
#define Aghb     SBScriptAGHB
#define Ahom     SBScriptAHOM
#define Arab     SBScriptARAB
#define Armi     SBScriptARMI
#define Armn     SBScriptARMN
#define Avst     SBScriptAVST
#define Bali     SBScriptBALI
#define Bamu     SBScriptBAMU
#define Bass     SBScriptBASS
#define Batk     SBScriptBATK
#define Beng     SBScriptBENG
#define Bhks     SBScriptBHKS
#define Bopo     SBScriptBOPO
#define Brah     SBScriptBRAH
#define Brai     SBScriptBRAI
#define Bugi     SBScriptBUGI
#define Buhd     SBScriptBUHD
#define Cakm     SBScriptCAKM
#define Cans     SBScriptCANS
#define Cari     SBScriptCARI
#define Cham     SBScriptCHAM
#define Cher     SBScriptCHER
#define Chrs     SBScriptCHRS
#define Copt     SBScriptCOPT
#define Cprt     SBScriptCPRT
#define Cyrl     SBScriptCYRL
#define Deva     SBScriptDEVA
#define Diak     SBScriptDIAK
#define Dogr     SBScriptDOGR
#define Dsrt     SBScriptDSRT
#define Dupl     SBScriptDUPL
#define Egyp     SBScriptEGYP
#define Elba     SBScriptELBA
#define Elym     SBScriptELYM
#define Ethi     SBScriptETHI
#define Geor     SBScriptGEOR
#define Glag     SBScriptGLAG
#define Gong     SBScriptGONG
#define Gonm     SBScriptGONM
#define Goth     SBScriptGOTH
#define Gran     SBScriptGRAN
#define Grek     SBScriptGREK
#define Gujr     SBScriptGUJR
#define Guru     SBScriptGURU
#define Hang     SBScriptHANG
#define Hani     SBScriptHANI
#define Hano     SBScriptHANO
#define Hatr     SBScriptHATR
#define Hebr     SBScriptHEBR
#define Hira     SBScriptHIRA
#define Hluw     SBScriptHLUW
#define Hmng     SBScriptHMNG
#define Hmnp     SBScriptHMNP
#define Hung     SBScriptHUNG
#define Ital     SBScriptITAL
#define Java     SBScriptJAVA
#define Kali     SBScriptKALI
#define Kana     SBScriptKANA
#define Khar     SBScriptKHAR
#define Khmr     SBScriptKHMR
#define Khoj     SBScriptKHOJ
#define Kits     SBScriptKITS
#define Knda     SBScriptKNDA
#define Kthi     SBScriptKTHI
#define Lana     SBScriptLANA
#define Laoo     SBScriptLAOO
#define Latn     SBScriptLATN
#define Lepc     SBScriptLEPC
#define Limb     SBScriptLIMB
#define Lina     SBScriptLINA
#define Linb     SBScriptLINB
#define Lisu     SBScriptLISU
#define Lyci     SBScriptLYCI
#define Lydi     SBScriptLYDI
#define Mahj     SBScriptMAHJ
#define Maka     SBScriptMAKA
#define Mand     SBScriptMAND
#define Mani     SBScriptMANI
#define Marc     SBScriptMARC
#define Medf     SBScriptMEDF
#define Mend     SBScriptMEND
#define Merc     SBScriptMERC
#define Mero     SBScriptMERO
#define Mlym     SBScriptMLYM
#define Modi     SBScriptMODI
#define Mong     SBScriptMONG
#define Mroo     SBScriptMROO
#define Mtei     SBScriptMTEI
#define Mult     SBScriptMULT
#define Mymr     SBScriptMYMR
#define Nand     SBScriptNAND
#define Narb     SBScriptNARB
#define Nbat     SBScriptNBAT
#define Newa     SBScriptNEWA
#define Nkoo     SBScriptNKOO
#define Nshu     SBScriptNSHU
#define Ogam     SBScriptOGAM
#define Olck     SBScriptOLCK
#define Orkh     SBScriptORKH
#define Orya     SBScriptORYA
#define Osge     SBScriptOSGE
#define Osma     SBScriptOSMA
#define Palm     SBScriptPALM
#define Pauc     SBScriptPAUC
#define Perm     SBScriptPERM
#define Phag     SBScriptPHAG
#define Phli     SBScriptPHLI
#define Phlp     SBScriptPHLP
#define Phnx     SBScriptPHNX
#define Plrd     SBScriptPLRD
#define Prti     SBScriptPRTI
#define Rjng     SBScriptRJNG
#define Rohg     SBScriptROHG
#define Runr     SBScriptRUNR
#define Samr     SBScriptSAMR
#define Sarb     SBScriptSARB
#define Saur     SBScriptSAUR
#define Sgnw     SBScriptSGNW
#define Shaw     SBScriptSHAW
#define Shrd     SBScriptSHRD
#define Sidd     SBScriptSIDD
#define Sind     SBScriptSIND
#define Sinh     SBScriptSINH
#define Sogd     SBScriptSOGD
#define Sogo     SBScriptSOGO
#define Sora     SBScriptSORA
#define Soyo     SBScriptSOYO
#define Sund     SBScriptSUND
#define Sylo     SBScriptSYLO
#define Syrc     SBScriptSYRC
#define Tagb     SBScriptTAGB
#define Takr     SBScriptTAKR
#define Tale     SBScriptTALE
#define Talu     SBScriptTALU
#define Taml     SBScriptTAML
#define Tang     SBScriptTANG
#define Tavt     SBScriptTAVT
#define Telu     SBScriptTELU
#define Tfng     SBScriptTFNG
#define Tglg     SBScriptTGLG
#define Thaa     SBScriptTHAA
#define Thai     SBScriptTHAI
#define Tibt     SBScriptTIBT
#define Tirh     SBScriptTIRH
#define Ugar     SBScriptUGAR
#define Vaii     SBScriptVAII
#define Wara     SBScriptWARA
#define Wcho     SBScriptWCHO
#define Xpeo     SBScriptXPEO
#define Xsux     SBScriptXSUX
#define Yezi     SBScriptYEZI
#define Yiii     SBScriptYIII
#define Zanb     SBScriptZANB
#define Zinh     SBScriptZINH
#define Zyyy     SBScriptZYYY
#define Zzzz     SBScriptZZZZ

static const SBUInt8 PrimaryScriptData[10304] = {
/* DATA_BLOCK: -- 0x0000..0x000F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0010..0x001F -- */
    Zyyy, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0020..0x002F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0030..0x003F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Latn, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0040..0x004F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0050..0x005F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0060..0x006F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0070..0x007F -- */
    Latn, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Bopo, Bopo, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0080..0x008F -- */
    Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh,
/* DATA_BLOCK: -- 0x0090..0x009F -- */
    Grek, Grek, Grek, Grek, Zyyy, Grek, Grek, Grek, Zzzz, Zzzz, Grek, Grek, Grek, Grek, Zyyy, Grek,
/* DATA_BLOCK: -- 0x00A0..0x00AF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Grek, Zyyy, Grek, Zyyy, Grek, Grek, Grek, Zzzz, Grek, Zzzz, Grek, Grek,
/* DATA_BLOCK: -- 0x00B0..0x00BF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek,
/* DATA_BLOCK: -- 0x00C0..0x00CF -- */
    Grek, Grek, Zzzz, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek,
/* DATA_BLOCK: -- 0x00D0..0x00DF -- */
    Grek, Grek, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt,
/* DATA_BLOCK: -- 0x00E0..0x00EF -- */
    Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl,
/* DATA_BLOCK: -- 0x00F0..0x00FF -- */
    Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Zinh, Zinh, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl,
/* DATA_BLOCK: -- 0x0100..0x010F -- */
    Zzzz, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn,
/* DATA_BLOCK: -- 0x0110..0x011F -- */
    Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn,
/* DATA_BLOCK: -- 0x0120..0x012F -- */
    Armn, Armn, Armn, Armn, Armn, Armn, Armn, Zzzz, Zzzz, Armn, Armn, Armn, Armn, Armn, Armn, Armn,
/* DATA_BLOCK: -- 0x0130..0x013F -- */
    Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Armn, Zzzz, Zzzz, Armn, Armn, Armn,
/* DATA_BLOCK: -- 0x0140..0x014F -- */
    Zzzz, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr,
/* DATA_BLOCK: -- 0x0150..0x015F -- */
    Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr,
/* DATA_BLOCK: -- 0x0160..0x016F -- */
    Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0170..0x017F -- */
    Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Zzzz, Zzzz, Zzzz, Zzzz, Hebr,
/* DATA_BLOCK: -- 0x0180..0x018F -- */
    Hebr, Hebr, Hebr, Hebr, Hebr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0190..0x019F -- */
    Arab, Arab, Arab, Arab, Arab, Zyyy, Arab, Arab, Arab, Arab, Arab, Arab, Zyyy, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x01A0..0x01AF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zyyy, Arab, Zzzz, Arab, Zyyy,
/* DATA_BLOCK: -- 0x01B0..0x01BF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x01C0..0x01CF -- */
    Zyyy, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zinh, Zinh, Zinh, Zinh, Zinh,
/* DATA_BLOCK: -- 0x01D0..0x01DF -- */
    Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x01E0..0x01EF -- */
    Zinh, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x01F0..0x01FF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zyyy, Arab, Arab,
/* DATA_BLOCK: -- 0x0200..0x020F -- */
    Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Zzzz, Syrc,
/* DATA_BLOCK: -- 0x0210..0x021F -- */
    Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc,
/* DATA_BLOCK: -- 0x0220..0x022F -- */
    Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Zzzz, Zzzz, Syrc, Syrc, Syrc,
/* DATA_BLOCK: -- 0x0230..0x023F -- */
    Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa, Thaa,
/* DATA_BLOCK: -- 0x0240..0x024F -- */
    Thaa, Thaa, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0250..0x025F -- */
    Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo,
/* DATA_BLOCK: -- 0x0260..0x026F -- */
    Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Nkoo, Zzzz, Zzzz, Nkoo, Nkoo, Nkoo,
/* DATA_BLOCK: -- 0x0270..0x027F -- */
    Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr,
/* DATA_BLOCK: -- 0x0280..0x028F -- */
    Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0290..0x029F -- */
    Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Samr, Zzzz,
/* DATA_BLOCK: -- 0x02A0..0x02AF -- */
    Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand,
/* DATA_BLOCK: -- 0x02B0..0x02BF -- */
    Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Mand, Zzzz, Zzzz, Mand, Zzzz,
/* DATA_BLOCK: -- 0x02C0..0x02CF -- */
    Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Syrc, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x02D0..0x02DF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x02E0..0x02EF -- */
    Arab, Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x02F0..0x02FF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0300..0x030F -- */
    Zzzz, Zzzz, Zzzz, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x0310..0x031F -- */
    Arab, Arab, Zyyy, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x0320..0x032F -- */
    Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva,
/* DATA_BLOCK: -- 0x0330..0x033F -- */
    Deva, Zinh, Zinh, Zinh, Zinh, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva,
/* DATA_BLOCK: -- 0x0340..0x034F -- */
    Deva, Deva, Deva, Deva, Zyyy, Zyyy, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva, Deva,
/* DATA_BLOCK: -- 0x0350..0x035F -- */
    Beng, Beng, Beng, Beng, Zzzz, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Zzzz, Zzzz, Beng,
/* DATA_BLOCK: -- 0x0360..0x036F -- */
    Beng, Zzzz, Zzzz, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng,
/* DATA_BLOCK: -- 0x0370..0x037F -- */
    Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Zzzz, Beng, Beng, Beng, Beng, Beng, Beng,
/* DATA_BLOCK: -- 0x0380..0x038F -- */
    Beng, Zzzz, Beng, Zzzz, Zzzz, Zzzz, Beng, Beng, Beng, Beng, Zzzz, Zzzz, Beng, Beng, Beng, Beng,
/* DATA_BLOCK: -- 0x0390..0x039F -- */
    Beng, Beng, Beng, Beng, Beng, Zzzz, Zzzz, Beng, Beng, Zzzz, Zzzz, Beng, Beng, Beng, Beng, Zzzz,
/* DATA_BLOCK: -- 0x03A0..0x03AF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Beng, Zzzz, Zzzz, Zzzz, Zzzz, Beng, Beng, Zzzz, Beng,
/* DATA_BLOCK: -- 0x03B0..0x03BF -- */
    Beng, Beng, Beng, Beng, Zzzz, Zzzz, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng,
/* DATA_BLOCK: -- 0x03C0..0x03CF -- */
    Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Beng, Zzzz,
/* DATA_BLOCK: -- 0x03D0..0x03DF -- */
    Zzzz, Guru, Guru, Guru, Zzzz, Guru, Guru, Guru, Guru, Guru, Guru, Zzzz, Zzzz, Zzzz, Zzzz, Guru,
/* DATA_BLOCK: -- 0x03E0..0x03EF -- */
    Guru, Zzzz, Zzzz, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru,
/* DATA_BLOCK: -- 0x03F0..0x03FF -- */
    Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Zzzz, Guru, Guru, Guru, Guru, Guru, Guru,
/* DATA_BLOCK: -- 0x0400..0x040F -- */
    Guru, Zzzz, Guru, Guru, Zzzz, Guru, Guru, Zzzz, Guru, Guru, Zzzz, Zzzz, Guru, Zzzz, Guru, Guru,
/* DATA_BLOCK: -- 0x0410..0x041F -- */
    Guru, Guru, Guru, Zzzz, Zzzz, Zzzz, Zzzz, Guru, Guru, Zzzz, Zzzz, Guru, Guru, Guru, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0420..0x042F -- */
    Zzzz, Guru, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Guru, Guru, Guru, Guru, Zzzz, Guru, Zzzz,
/* DATA_BLOCK: -- 0x0430..0x043F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru, Guru,
/* DATA_BLOCK: -- 0x0440..0x044F -- */
    Guru, Guru, Guru, Guru, Guru, Guru, Guru, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0450..0x045F -- */
    Zzzz, Gujr, Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Zzzz, Gujr,
/* DATA_BLOCK: -- 0x0460..0x046F -- */
    Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr,
/* DATA_BLOCK: -- 0x0470..0x047F -- */
    Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr,
/* DATA_BLOCK: -- 0x0480..0x048F -- */
    Gujr, Zzzz, Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Zzzz, Zzzz, Gujr, Gujr, Gujr, Gujr,
/* DATA_BLOCK: -- 0x0490..0x049F -- */
    Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Zzzz, Gujr, Gujr, Gujr, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x04A0..0x04AF -- */
    Gujr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x04B0..0x04BF -- */
    Gujr, Gujr, Gujr, Gujr, Zzzz, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr,
/* DATA_BLOCK: -- 0x04C0..0x04CF -- */
    Gujr, Gujr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr, Gujr,
/* DATA_BLOCK: -- 0x04D0..0x04DF -- */
    Zzzz, Orya, Orya, Orya, Zzzz, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Zzzz, Zzzz, Orya,
/* DATA_BLOCK: -- 0x04E0..0x04EF -- */
    Orya, Zzzz, Zzzz, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya,
/* DATA_BLOCK: -- 0x04F0..0x04FF -- */
    Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Zzzz, Orya, Orya, Orya, Orya, Orya, Orya,
/* DATA_BLOCK: -- 0x0500..0x050F -- */
    Orya, Zzzz, Orya, Orya, Zzzz, Orya, Orya, Orya, Orya, Orya, Zzzz, Zzzz, Orya, Orya, Orya, Orya,
/* DATA_BLOCK: -- 0x0510..0x051F -- */
    Orya, Orya, Orya, Orya, Orya, Zzzz, Zzzz, Orya, Orya, Zzzz, Zzzz, Orya, Orya, Orya, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0520..0x052F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Orya, Orya, Orya, Zzzz, Zzzz, Zzzz, Zzzz, Orya, Orya, Zzzz, Orya,
/* DATA_BLOCK: -- 0x0530..0x053F -- */
    Orya, Orya, Orya, Orya, Zzzz, Zzzz, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya,
/* DATA_BLOCK: -- 0x0540..0x054F -- */
    Orya, Orya, Orya, Orya, Orya, Orya, Orya, Orya, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0550..0x055F -- */
    Zzzz, Zzzz, Taml, Taml, Zzzz, Taml, Taml, Taml, Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Taml, Taml,
/* DATA_BLOCK: -- 0x0560..0x056F -- */
    Taml, Zzzz, Taml, Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Taml, Taml, Zzzz, Taml, Zzzz, Taml, Taml,
/* DATA_BLOCK: -- 0x0570..0x057F -- */
    Zzzz, Zzzz, Zzzz, Taml, Taml, Zzzz, Zzzz, Zzzz, Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Taml, Taml,
/* DATA_BLOCK: -- 0x0580..0x058F -- */
    Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Zzzz, Taml, Taml,
/* DATA_BLOCK: -- 0x0590..0x059F -- */
    Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Taml, Taml, Taml, Zzzz, Taml, Taml, Taml, Taml, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x05A0..0x05AF -- */
    Taml, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Taml, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x05B0..0x05BF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml,
/* DATA_BLOCK: -- 0x05C0..0x05CF -- */
    Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x05D0..0x05DF -- */
    Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Zzzz, Telu, Telu,
/* DATA_BLOCK: -- 0x05E0..0x05EF -- */
    Telu, Zzzz, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu,
/* DATA_BLOCK: -- 0x05F0..0x05FF -- */
    Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Zzzz, Telu, Telu, Telu, Telu, Telu, Telu,
/* DATA_BLOCK: -- 0x0600..0x060F -- */
    Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Zzzz, Zzzz, Zzzz, Telu, Telu, Telu,
/* DATA_BLOCK: -- 0x0610..0x061F -- */
    Telu, Telu, Telu, Telu, Telu, Zzzz, Telu, Telu, Telu, Zzzz, Telu, Telu, Telu, Telu, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0620..0x062F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Telu, Telu, Zzzz, Telu, Telu, Telu, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0630..0x063F -- */
    Telu, Telu, Telu, Telu, Zzzz, Zzzz, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu,
/* DATA_BLOCK: -- 0x0640..0x064F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu, Telu,
/* DATA_BLOCK: -- 0x0650..0x065F -- */
    Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Zzzz, Knda, Knda,
/* DATA_BLOCK: -- 0x0660..0x066F -- */
    Knda, Zzzz, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda,
/* DATA_BLOCK: -- 0x0670..0x067F -- */
    Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Zzzz, Knda, Knda, Knda, Knda, Knda, Knda,
/* DATA_BLOCK: -- 0x0680..0x068F -- */
    Knda, Knda, Knda, Knda, Zzzz, Knda, Knda, Knda, Knda, Knda, Zzzz, Zzzz, Knda, Knda, Knda, Knda,
/* DATA_BLOCK: -- 0x0690..0x069F -- */
    Knda, Knda, Knda, Knda, Knda, Zzzz, Knda, Knda, Knda, Zzzz, Knda, Knda, Knda, Knda, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x06A0..0x06AF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Knda, Knda, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Knda, Zzzz,
/* DATA_BLOCK: -- 0x06B0..0x06BF -- */
    Knda, Knda, Knda, Knda, Zzzz, Zzzz, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda, Knda,
/* DATA_BLOCK: -- 0x06C0..0x06CF -- */
    Zzzz, Knda, Knda, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x06D0..0x06DF -- */
    Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Zzzz, Mlym, Mlym,
/* DATA_BLOCK: -- 0x06E0..0x06EF -- */
    Mlym, Zzzz, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym,
/* DATA_BLOCK: -- 0x06F0..0x06FF -- */
    Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym,
/* DATA_BLOCK: -- 0x0700..0x070F -- */
    Mlym, Mlym, Mlym, Mlym, Mlym, Zzzz, Mlym, Mlym, Mlym, Zzzz, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym,
/* DATA_BLOCK: -- 0x0710..0x071F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym,
/* DATA_BLOCK: -- 0x0720..0x072F -- */
    Mlym, Mlym, Mlym, Mlym, Zzzz, Zzzz, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym, Mlym,
/* DATA_BLOCK: -- 0x0730..0x073F -- */
    Zzzz, Sinh, Sinh, Sinh, Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x0740..0x074F -- */
    Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Zzzz, Zzzz, Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x0750..0x075F -- */
    Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x0760..0x076F -- */
    Sinh, Sinh, Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Zzzz, Sinh, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0770..0x077F -- */
    Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Zzzz, Zzzz, Zzzz, Sinh, Zzzz, Zzzz, Zzzz, Zzzz, Sinh,
/* DATA_BLOCK: -- 0x0780..0x078F -- */
    Sinh, Sinh, Sinh, Sinh, Sinh, Zzzz, Sinh, Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x0790..0x079F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x07A0..0x07AF -- */
    Zzzz, Zzzz, Sinh, Sinh, Sinh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x07B0..0x07BF -- */
    Zzzz, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai,
/* DATA_BLOCK: -- 0x07C0..0x07CF -- */
    Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai,
/* DATA_BLOCK: -- 0x07D0..0x07DF -- */
    Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Zzzz, Zzzz, Zzzz, Zzzz, Zyyy,
/* DATA_BLOCK: -- 0x07E0..0x07EF -- */
    Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Thai, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x07F0..0x07FF -- */
    Zzzz, Laoo, Laoo, Zzzz, Laoo, Zzzz, Laoo, Laoo, Laoo, Laoo, Laoo, Zzzz, Laoo, Laoo, Laoo, Laoo,
/* DATA_BLOCK: -- 0x0800..0x080F -- */
    Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo,
/* DATA_BLOCK: -- 0x0810..0x081F -- */
    Laoo, Laoo, Laoo, Laoo, Zzzz, Laoo, Zzzz, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo,
/* DATA_BLOCK: -- 0x0820..0x082F -- */
    Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0830..0x083F -- */
    Laoo, Laoo, Laoo, Laoo, Laoo, Zzzz, Laoo, Zzzz, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0840..0x084F -- */
    Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Laoo, Zzzz, Zzzz, Laoo, Laoo, Laoo, Laoo,
/* DATA_BLOCK: -- 0x0850..0x085F -- */
    Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt,
/* DATA_BLOCK: -- 0x0860..0x086F -- */
    Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Zzzz, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt,
/* DATA_BLOCK: -- 0x0870..0x087F -- */
    Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0880..0x088F -- */
    Zzzz, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt,
/* DATA_BLOCK: -- 0x0890..0x089F -- */
    Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Tibt, Zzzz, Tibt, Tibt,
/* DATA_BLOCK: -- 0x08A0..0x08AF -- */
    Tibt, Tibt, Tibt, Tibt, Tibt, Zyyy, Zyyy, Zyyy, Zyyy, Tibt, Tibt, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x08B0..0x08BF -- */
    Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr,
/* DATA_BLOCK: -- 0x08C0..0x08CF -- */
    Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor,
/* DATA_BLOCK: -- 0x08D0..0x08DF -- */
    Geor, Geor, Geor, Geor, Geor, Geor, Zzzz, Geor, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Geor, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x08E0..0x08EF -- */
    Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Zyyy, Geor, Geor, Geor, Geor,
/* DATA_BLOCK: -- 0x08F0..0x08FF -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang,
/* DATA_BLOCK: -- 0x0900..0x090F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi,
/* DATA_BLOCK: -- 0x0910..0x091F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0920..0x092F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0930..0x093F -- */
    Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz,
/* DATA_BLOCK: -- 0x0940..0x094F -- */
    Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi,
/* DATA_BLOCK: -- 0x0950..0x095F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi,
/* DATA_BLOCK: -- 0x0960..0x096F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Ethi, Ethi, Ethi,
/* DATA_BLOCK: -- 0x0970..0x097F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0980..0x098F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0990..0x099F -- */
    Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher, Cher,
/* DATA_BLOCK: -- 0x09A0..0x09AF -- */
    Cher, Cher, Cher, Cher, Cher, Cher, Zzzz, Zzzz, Cher, Cher, Cher, Cher, Cher, Cher, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x09B0..0x09BF -- */
    Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans, Cans,
/* DATA_BLOCK: -- 0x09C0..0x09CF -- */
    Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam,
/* DATA_BLOCK: -- 0x09D0..0x09DF -- */
    Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Ogam, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x09E0..0x09EF -- */
    Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr,
/* DATA_BLOCK: -- 0x09F0..0x09FF -- */
    Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Zyyy, Zyyy, Zyyy, Runr, Runr,
/* DATA_BLOCK: -- 0x0A00..0x0A0F -- */
    Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Runr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0A10..0x0A1F -- */
    Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Tglg, Zzzz, Tglg, Tglg,
/* DATA_BLOCK: -- 0x0A20..0x0A2F -- */
    Tglg, Tglg, Tglg, Tglg, Tglg, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0A30..0x0A3F -- */
    Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano, Hano,
/* DATA_BLOCK: -- 0x0A40..0x0A4F -- */
    Hano, Hano, Hano, Hano, Hano, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0A50..0x0A5F -- */
    Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd, Buhd,
/* DATA_BLOCK: -- 0x0A60..0x0A6F -- */
    Buhd, Buhd, Buhd, Buhd, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0A70..0x0A7F -- */
    Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Tagb, Zzzz, Tagb, Tagb,
/* DATA_BLOCK: -- 0x0A80..0x0A8F -- */
    Tagb, Zzzz, Tagb, Tagb, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0A90..0x0A9F -- */
    Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr,
/* DATA_BLOCK: -- 0x0AA0..0x0AAF -- */
    Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0AB0..0x0ABF -- */
    Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Khmr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0AC0..0x0ACF -- */
    Mong, Mong, Zyyy, Zyyy, Mong, Zyyy, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Zzzz,
/* DATA_BLOCK: -- 0x0AD0..0x0ADF -- */
    Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0AE0..0x0AEF -- */
    Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong,
/* DATA_BLOCK: -- 0x0AF0..0x0AFF -- */
    Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B00..0x0B0F -- */
    Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B10..0x0B1F -- */
    Cans, Cans, Cans, Cans, Cans, Cans, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B20..0x0B2F -- */
    Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb,
/* DATA_BLOCK: -- 0x0B30..0x0B3F -- */
    Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Zzzz,
/* DATA_BLOCK: -- 0x0B40..0x0B4F -- */
    Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B50..0x0B5F -- */
    Limb, Zzzz, Zzzz, Zzzz, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb, Limb,
/* DATA_BLOCK: -- 0x0B60..0x0B6F -- */
    Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale,
/* DATA_BLOCK: -- 0x0B70..0x0B7F -- */
    Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Tale, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B80..0x0B8F -- */
    Tale, Tale, Tale, Tale, Tale, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0B90..0x0B9F -- */
    Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu,
/* DATA_BLOCK: -- 0x0BA0..0x0BAF -- */
    Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0BB0..0x0BBF -- */
    Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0BC0..0x0BCF -- */
    Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Talu, Zzzz, Zzzz, Zzzz, Talu, Talu,
/* DATA_BLOCK: -- 0x0BD0..0x0BDF -- */
    Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi,
/* DATA_BLOCK: -- 0x0BE0..0x0BEF -- */
    Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Bugi, Zzzz, Zzzz, Bugi, Bugi,
/* DATA_BLOCK: -- 0x0BF0..0x0BFF -- */
    Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana,
/* DATA_BLOCK: -- 0x0C00..0x0C0F -- */
    Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Zzzz,
/* DATA_BLOCK: -- 0x0C10..0x0C1F -- */
    Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Zzzz, Zzzz, Lana,
/* DATA_BLOCK: -- 0x0C20..0x0C2F -- */
    Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0C30..0x0C3F -- */
    Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Lana, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0C40..0x0C4F -- */
    Zinh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0C50..0x0C5F -- */
    Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali,
/* DATA_BLOCK: -- 0x0C60..0x0C6F -- */
    Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0C70..0x0C7F -- */
    Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Bali, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0C80..0x0C8F -- */
    Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund,
/* DATA_BLOCK: -- 0x0C90..0x0C9F -- */
    Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk, Batk,
/* DATA_BLOCK: -- 0x0CA0..0x0CAF -- */
    Batk, Batk, Batk, Batk, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Batk, Batk, Batk, Batk,
/* DATA_BLOCK: -- 0x0CB0..0x0CBF -- */
    Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc,
/* DATA_BLOCK: -- 0x0CC0..0x0CCF -- */
    Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Zzzz, Zzzz, Zzzz, Lepc, Lepc, Lepc, Lepc, Lepc,
/* DATA_BLOCK: -- 0x0CD0..0x0CDF -- */
    Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Lepc, Zzzz, Zzzz, Zzzz, Lepc, Lepc, Lepc,
/* DATA_BLOCK: -- 0x0CE0..0x0CEF -- */
    Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck, Olck,
/* DATA_BLOCK: -- 0x0CF0..0x0CFF -- */
    Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Cyrl, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0D00..0x0D0F -- */
    Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Geor, Zzzz, Zzzz, Geor, Geor, Geor,
/* DATA_BLOCK: -- 0x0D10..0x0D1F -- */
    Sund, Sund, Sund, Sund, Sund, Sund, Sund, Sund, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0D20..0x0D2F -- */
    Zinh, Zinh, Zinh, Zyyy, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh,
/* DATA_BLOCK: -- 0x0D30..0x0D3F -- */
    Zinh, Zyyy, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0D40..0x0D4F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zyyy, Zyyy, Zyyy, Zinh, Zinh, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0D50..0x0D5F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Grek, Grek, Grek, Grek, Grek, Cyrl, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0D60..0x0D6F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Grek, Grek, Grek,
/* DATA_BLOCK: -- 0x0D70..0x0D7F -- */
    Grek, Grek, Latn, Latn, Latn, Latn, Grek, Grek, Grek, Grek, Grek, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0D80..0x0D8F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Cyrl, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x0D90..0x0D9F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Grek,
/* DATA_BLOCK: -- 0x0DA0..0x0DAF -- */
    Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zzzz, Zinh, Zinh, Zinh, Zinh, Zinh,
/* DATA_BLOCK: -- 0x0DB0..0x0DBF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Zzzz, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0DC0..0x0DCF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Grek, Zzzz, Grek, Zzzz, Grek, Zzzz, Grek,
/* DATA_BLOCK: -- 0x0DD0..0x0DDF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0DE0..0x0DEF -- */
    Grek, Grek, Grek, Grek, Grek, Zzzz, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek,
/* DATA_BLOCK: -- 0x0DF0..0x0DFF -- */
    Grek, Grek, Grek, Grek, Zzzz, Zzzz, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Grek, Grek, Grek,
/* DATA_BLOCK: -- 0x0E00..0x0E0F -- */
    Zzzz, Zzzz, Grek, Grek, Grek, Zzzz, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz,
/* DATA_BLOCK: -- 0x0E10..0x0E1F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zinh, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0E20..0x0E2F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0E30..0x0E3F -- */
    Zyyy, Latn, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Latn,
/* DATA_BLOCK: -- 0x0E40..0x0E4F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz,
/* DATA_BLOCK: -- 0x0E50..0x0E5F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0E60..0x0E6F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Grek, Zyyy, Zyyy, Zyyy, Latn, Latn, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0E70..0x0E7F -- */
    Zyyy, Zyyy, Latn, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0E80..0x0E8F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Latn, Zyyy,
/* DATA_BLOCK: -- 0x0E90..0x0E9F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0EA0..0x0EAF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0EB0..0x0EBF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0EC0..0x0ECF -- */
    Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai, Brai,
/* DATA_BLOCK: -- 0x0ED0..0x0EDF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0EE0..0x0EEF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0EF0..0x0EFF -- */
    Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag,
/* DATA_BLOCK: -- 0x0F00..0x0F0F -- */
    Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Zzzz,
/* DATA_BLOCK: -- 0x0F10..0x0F1F -- */
    Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt, Copt,
/* DATA_BLOCK: -- 0x0F20..0x0F2F -- */
    Copt, Copt, Copt, Copt, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Copt, Copt, Copt, Copt, Copt, Copt, Copt,
/* DATA_BLOCK: -- 0x0F30..0x0F3F -- */
    Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng,
/* DATA_BLOCK: -- 0x0F40..0x0F4F -- */
    Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Tfng, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Tfng,
/* DATA_BLOCK: -- 0x0F50..0x0F5F -- */
    Tfng, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Tfng,
/* DATA_BLOCK: -- 0x0F60..0x0F6F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0F70..0x0F7F -- */
    Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz,
/* DATA_BLOCK: -- 0x0F80..0x0F8F -- */
    Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0F90..0x0F9F -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani,
/* DATA_BLOCK: -- 0x0FA0..0x0FAF -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Hani, Hani, Hani, Hani, Hani,
/* DATA_BLOCK: -- 0x0FB0..0x0FBF -- */
    Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0FC0..0x0FCF -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0FD0..0x0FDF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x0FE0..0x0FEF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Hani, Zyyy, Hani, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x0FF0..0x0FFF -- */
    Zyyy, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zinh, Zinh, Zinh, Zinh, Hang, Hang,
/* DATA_BLOCK: -- 0x1000..0x100F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Hani, Hani, Hani, Hani, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x1010..0x101F -- */
    Zzzz, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira,
/* DATA_BLOCK: -- 0x1020..0x102F -- */
    Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira,
/* DATA_BLOCK: -- 0x1030..0x103F -- */
    Hira, Hira, Hira, Hira, Hira, Hira, Hira, Zzzz, Zzzz, Zinh, Zinh, Zyyy, Zyyy, Hira, Hira, Hira,
/* DATA_BLOCK: -- 0x1040..0x104F -- */
    Zyyy, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana,
/* DATA_BLOCK: -- 0x1050..0x105F -- */
    Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana,
/* DATA_BLOCK: -- 0x1060..0x106F -- */
    Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Zyyy, Zyyy, Kana, Kana, Kana,
/* DATA_BLOCK: -- 0x1070..0x107F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo,
/* DATA_BLOCK: -- 0x1080..0x108F -- */
    Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo, Bopo,
/* DATA_BLOCK: -- 0x1090..0x109F -- */
    Zzzz, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang,
/* DATA_BLOCK: -- 0x10A0..0x10AF -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz,
/* DATA_BLOCK: -- 0x10B0..0x10BF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x10C0..0x10CF -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Zyyy,
/* DATA_BLOCK: -- 0x10D0..0x10DF -- */
    Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Zyyy,
/* DATA_BLOCK: -- 0x10E0..0x10EF -- */
    Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x10F0..0x10FF -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1100..0x110F -- */
    Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii,
/* DATA_BLOCK: -- 0x1110..0x111F -- */
    Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1120..0x112F -- */
    Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Yiii, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1130..0x113F -- */
    Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu, Lisu,
/* DATA_BLOCK: -- 0x1140..0x114F -- */
    Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii,
/* DATA_BLOCK: -- 0x1150..0x115F -- */
    Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Vaii, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1160..0x116F -- */
    Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu,
/* DATA_BLOCK: -- 0x1170..0x117F -- */
    Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1180..0x118F -- */
    Zyyy, Zyyy, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x1190..0x119F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zyyy, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x11A0..0x11AF -- */
    Zzzz, Zzzz, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x11B0..0x11BF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x11C0..0x11CF -- */
    Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo,
/* DATA_BLOCK: -- 0x11D0..0x11DF -- */
    Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Sylo, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x11E0..0x11EF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x11F0..0x11FF -- */
    Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag,
/* DATA_BLOCK: -- 0x1200..0x120F -- */
    Phag, Phag, Phag, Phag, Phag, Phag, Phag, Phag, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1210..0x121F -- */
    Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur,
/* DATA_BLOCK: -- 0x1220..0x122F -- */
    Saur, Saur, Saur, Saur, Saur, Saur, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Saur, Saur,
/* DATA_BLOCK: -- 0x1230..0x123F -- */
    Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Saur, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1240..0x124F -- */
    Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali,
/* DATA_BLOCK: -- 0x1250..0x125F -- */
    Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Kali, Zyyy, Kali,
/* DATA_BLOCK: -- 0x1260..0x126F -- */
    Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng, Rjng,
/* DATA_BLOCK: -- 0x1270..0x127F -- */
    Rjng, Rjng, Rjng, Rjng, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Rjng,
/* DATA_BLOCK: -- 0x1280..0x128F -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1290..0x129F -- */
    Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java,
/* DATA_BLOCK: -- 0x12A0..0x12AF -- */
    Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Zzzz, Zyyy,
/* DATA_BLOCK: -- 0x12B0..0x12BF -- */
    Java, Java, Java, Java, Java, Java, Java, Java, Java, Java, Zzzz, Zzzz, Zzzz, Zzzz, Java, Java,
/* DATA_BLOCK: -- 0x12C0..0x12CF -- */
    Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Mymr, Zzzz,
/* DATA_BLOCK: -- 0x12D0..0x12DF -- */
    Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham,
/* DATA_BLOCK: -- 0x12E0..0x12EF -- */
    Cham, Cham, Cham, Cham, Cham, Cham, Cham, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x12F0..0x12FF -- */
    Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1300..0x130F -- */
    Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Cham, Zzzz, Zzzz, Cham, Cham, Cham, Cham,
/* DATA_BLOCK: -- 0x1310..0x131F -- */
    Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt, Tavt,
/* DATA_BLOCK: -- 0x1320..0x132F -- */
    Tavt, Tavt, Tavt, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1330..0x133F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Tavt, Tavt, Tavt, Tavt, Tavt,
/* DATA_BLOCK: -- 0x1340..0x134F -- */
    Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei,
/* DATA_BLOCK: -- 0x1350..0x135F -- */
    Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1360..0x136F -- */
    Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz,
/* DATA_BLOCK: -- 0x1370..0x137F -- */
    Zzzz, Ethi, Ethi, Ethi, Ethi, Ethi, Ethi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1380..0x138F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zyyy, Latn, Latn, Latn, Latn,
/* DATA_BLOCK: -- 0x1390..0x139F -- */
    Latn, Latn, Latn, Latn, Latn, Grek, Latn, Latn, Latn, Latn, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x13A0..0x13AF -- */
    Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x13B0..0x13BF -- */
    Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Mtei, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x13C0..0x13CF -- */
    Hang, Hang, Hang, Hang, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x13D0..0x13DF -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz, Zzzz, Zzzz, Zzzz, Hang, Hang, Hang, Hang, Hang,
/* DATA_BLOCK: -- 0x13E0..0x13EF -- */
    Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x13F0..0x13FF -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1400..0x140F -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1410..0x141F -- */
    Latn, Latn, Latn, Latn, Latn, Latn, Latn, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1420..0x142F -- */
    Zzzz, Zzzz, Zzzz, Armn, Armn, Armn, Armn, Armn, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Hebr, Hebr, Hebr,
/* DATA_BLOCK: -- 0x1430..0x143F -- */
    Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Zzzz, Hebr, Hebr, Hebr, Hebr, Hebr, Zzzz, Hebr, Zzzz,
/* DATA_BLOCK: -- 0x1440..0x144F -- */
    Hebr, Hebr, Zzzz, Hebr, Hebr, Zzzz, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr, Hebr,
/* DATA_BLOCK: -- 0x1450..0x145F -- */
    Arab, Arab, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1460..0x146F -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x1470..0x147F -- */
    Zzzz, Zzzz, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x1480..0x148F -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1490..0x149F -- */
    Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Cyrl, Cyrl,
/* DATA_BLOCK: -- 0x14A0..0x14AF -- */
    Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x14B0..0x14BF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x14C0..0x14CF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz, Zzzz, Zyyy,
/* DATA_BLOCK: -- 0x14D0..0x14DF -- */
    Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x14E0..0x14EF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana,
/* DATA_BLOCK: -- 0x14F0..0x14FF -- */
    Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Kana, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x1500..0x150F -- */
    Zzzz, Zzzz, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz, Zzzz, Hang, Hang, Hang, Hang, Hang, Hang,
/* DATA_BLOCK: -- 0x1510..0x151F -- */
    Zzzz, Zzzz, Hang, Hang, Hang, Hang, Hang, Hang, Zzzz, Zzzz, Hang, Hang, Hang, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1520..0x152F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz,
/* DATA_BLOCK: -- 0x1530..0x153F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1540..0x154F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Zzzz, Linb, Linb, Linb,
/* DATA_BLOCK: -- 0x1550..0x155F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb,
/* DATA_BLOCK: -- 0x1560..0x156F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Zzzz, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb,
/* DATA_BLOCK: -- 0x1570..0x157F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Zzzz, Linb, Linb, Zzzz, Linb,
/* DATA_BLOCK: -- 0x1580..0x158F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1590..0x159F -- */
    Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Linb, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x15A0..0x15AF -- */
    Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x15B0..0x15BF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x15C0..0x15CF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Grek, Zzzz,
/* DATA_BLOCK: -- 0x15D0..0x15DF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x15E0..0x15EF -- */
    Grek, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x15F0..0x15FF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1600..0x160F -- */
    Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci,
/* DATA_BLOCK: -- 0x1610..0x161F -- */
    Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Lyci, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1620..0x162F -- */
    Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari, Cari,
/* DATA_BLOCK: -- 0x1630..0x163F -- */
    Cari, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1640..0x164F -- */
    Zinh, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x1650..0x165F -- */
    Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital, Ital,
/* DATA_BLOCK: -- 0x1660..0x166F -- */
    Ital, Ital, Ital, Ital, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Ital, Ital, Ital,
/* DATA_BLOCK: -- 0x1670..0x167F -- */
    Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth,
/* DATA_BLOCK: -- 0x1680..0x168F -- */
    Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Goth, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1690..0x169F -- */
    Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm,
/* DATA_BLOCK: -- 0x16A0..0x16AF -- */
    Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Perm, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x16B0..0x16BF -- */
    Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar,
/* DATA_BLOCK: -- 0x16C0..0x16CF -- */
    Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Ugar, Zzzz, Ugar,
/* DATA_BLOCK: -- 0x16D0..0x16DF -- */
    Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo,
/* DATA_BLOCK: -- 0x16E0..0x16EF -- */
    Xpeo, Xpeo, Xpeo, Xpeo, Zzzz, Zzzz, Zzzz, Zzzz, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo,
/* DATA_BLOCK: -- 0x16F0..0x16FF -- */
    Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Xpeo, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1700..0x170F -- */
    Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt, Dsrt,
/* DATA_BLOCK: -- 0x1710..0x171F -- */
    Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw, Shaw,
/* DATA_BLOCK: -- 0x1720..0x172F -- */
    Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma,
/* DATA_BLOCK: -- 0x1730..0x173F -- */
    Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1740..0x174F -- */
    Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Osma, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1750..0x175F -- */
    Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge,
/* DATA_BLOCK: -- 0x1760..0x176F -- */
    Osge, Osge, Osge, Osge, Zzzz, Zzzz, Zzzz, Zzzz, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge,
/* DATA_BLOCK: -- 0x1770..0x177F -- */
    Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Osge, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1780..0x178F -- */
    Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba,
/* DATA_BLOCK: -- 0x1790..0x179F -- */
    Elba, Elba, Elba, Elba, Elba, Elba, Elba, Elba, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x17A0..0x17AF -- */
    Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb, Aghb,
/* DATA_BLOCK: -- 0x17B0..0x17BF -- */
    Aghb, Aghb, Aghb, Aghb, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Aghb,
/* DATA_BLOCK: -- 0x17C0..0x17CF -- */
    Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina,
/* DATA_BLOCK: -- 0x17D0..0x17DF -- */
    Lina, Lina, Lina, Lina, Lina, Lina, Lina, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x17E0..0x17EF -- */
    Lina, Lina, Lina, Lina, Lina, Lina, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x17F0..0x17FF -- */
    Lina, Lina, Lina, Lina, Lina, Lina, Lina, Lina, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1800..0x180F -- */
    Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Zzzz, Zzzz, Cprt, Zzzz, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt,
/* DATA_BLOCK: -- 0x1810..0x181F -- */
    Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Cprt,
/* DATA_BLOCK: -- 0x1820..0x182F -- */
    Cprt, Cprt, Cprt, Cprt, Cprt, Cprt, Zzzz, Cprt, Cprt, Zzzz, Zzzz, Zzzz, Cprt, Zzzz, Zzzz, Cprt,
/* DATA_BLOCK: -- 0x1830..0x183F -- */
    Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi,
/* DATA_BLOCK: -- 0x1840..0x184F -- */
    Armi, Armi, Armi, Armi, Armi, Armi, Zzzz, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi, Armi,
/* DATA_BLOCK: -- 0x1850..0x185F -- */
    Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm, Palm,
/* DATA_BLOCK: -- 0x1860..0x186F -- */
    Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat,
/* DATA_BLOCK: -- 0x1870..0x187F -- */
    Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Zzzz,
/* DATA_BLOCK: -- 0x1880..0x188F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat, Nbat,
/* DATA_BLOCK: -- 0x1890..0x189F -- */
    Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr, Hatr,
/* DATA_BLOCK: -- 0x18A0..0x18AF -- */
    Hatr, Hatr, Hatr, Zzzz, Hatr, Hatr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Hatr, Hatr, Hatr, Hatr, Hatr,
/* DATA_BLOCK: -- 0x18B0..0x18BF -- */
    Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx,
/* DATA_BLOCK: -- 0x18C0..0x18CF -- */
    Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Phnx, Zzzz, Zzzz, Zzzz, Phnx,
/* DATA_BLOCK: -- 0x18D0..0x18DF -- */
    Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi,
/* DATA_BLOCK: -- 0x18E0..0x18EF -- */
    Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Lydi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Lydi,
/* DATA_BLOCK: -- 0x18F0..0x18FF -- */
    Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero, Mero,
/* DATA_BLOCK: -- 0x1900..0x190F -- */
    Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc,
/* DATA_BLOCK: -- 0x1910..0x191F -- */
    Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Zzzz, Zzzz, Zzzz, Zzzz, Merc, Merc, Merc, Merc,
/* DATA_BLOCK: -- 0x1920..0x192F -- */
    Zzzz, Zzzz, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc, Merc,
/* DATA_BLOCK: -- 0x1930..0x193F -- */
    Khar, Khar, Khar, Khar, Zzzz, Khar, Khar, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Khar, Khar, Khar, Khar,
/* DATA_BLOCK: -- 0x1940..0x194F -- */
    Khar, Khar, Khar, Khar, Zzzz, Khar, Khar, Khar, Zzzz, Khar, Khar, Khar, Khar, Khar, Khar, Khar,
/* DATA_BLOCK: -- 0x1950..0x195F -- */
    Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar,
/* DATA_BLOCK: -- 0x1960..0x196F -- */
    Khar, Khar, Khar, Khar, Khar, Khar, Zzzz, Zzzz, Khar, Khar, Khar, Zzzz, Zzzz, Zzzz, Zzzz, Khar,
/* DATA_BLOCK: -- 0x1970..0x197F -- */
    Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Khar, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1980..0x198F -- */
    Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb, Sarb,
/* DATA_BLOCK: -- 0x1990..0x199F -- */
    Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb, Narb,
/* DATA_BLOCK: -- 0x19A0..0x19AF -- */
    Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani, Mani,
/* DATA_BLOCK: -- 0x19B0..0x19BF -- */
    Mani, Mani, Mani, Mani, Mani, Mani, Mani, Zzzz, Zzzz, Zzzz, Zzzz, Mani, Mani, Mani, Mani, Mani,
/* DATA_BLOCK: -- 0x19C0..0x19CF -- */
    Mani, Mani, Mani, Mani, Mani, Mani, Mani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x19D0..0x19DF -- */
    Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst, Avst,
/* DATA_BLOCK: -- 0x19E0..0x19EF -- */
    Avst, Avst, Avst, Avst, Avst, Avst, Zzzz, Zzzz, Zzzz, Avst, Avst, Avst, Avst, Avst, Avst, Avst,
/* DATA_BLOCK: -- 0x19F0..0x19FF -- */
    Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti,
/* DATA_BLOCK: -- 0x1A00..0x1A0F -- */
    Prti, Prti, Prti, Prti, Prti, Prti, Zzzz, Zzzz, Prti, Prti, Prti, Prti, Prti, Prti, Prti, Prti,
/* DATA_BLOCK: -- 0x1A10..0x1A1F -- */
    Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli,
/* DATA_BLOCK: -- 0x1A20..0x1A2F -- */
    Phli, Phli, Phli, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Phli, Phli, Phli, Phli, Phli, Phli, Phli, Phli,
/* DATA_BLOCK: -- 0x1A30..0x1A3F -- */
    Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp,
/* DATA_BLOCK: -- 0x1A40..0x1A4F -- */
    Phlp, Phlp, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Phlp, Phlp, Phlp, Phlp, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1A50..0x1A5F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp, Phlp,
/* DATA_BLOCK: -- 0x1A60..0x1A6F -- */
    Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh,
/* DATA_BLOCK: -- 0x1A70..0x1A7F -- */
    Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Orkh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1A80..0x1A8F -- */
    Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung, Hung,
/* DATA_BLOCK: -- 0x1A90..0x1A9F -- */
    Hung, Hung, Hung, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1AA0..0x1AAF -- */
    Hung, Hung, Hung, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Hung, Hung, Hung, Hung, Hung, Hung,
/* DATA_BLOCK: -- 0x1AB0..0x1ABF -- */
    Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg,
/* DATA_BLOCK: -- 0x1AC0..0x1ACF -- */
    Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1AD0..0x1ADF -- */
    Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Rohg, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1AE0..0x1AEF -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz,
/* DATA_BLOCK: -- 0x1AF0..0x1AFF -- */
    Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi,
/* DATA_BLOCK: -- 0x1B00..0x1B0F -- */
    Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Yezi, Zzzz, Yezi, Yezi, Yezi, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1B10..0x1B1F -- */
    Yezi, Yezi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1B20..0x1B2F -- */
    Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo,
/* DATA_BLOCK: -- 0x1B30..0x1B3F -- */
    Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Sogo, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1B40..0x1B4F -- */
    Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd,
/* DATA_BLOCK: -- 0x1B50..0x1B5F -- */
    Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Sogd, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1B60..0x1B6F -- */
    Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs,
/* DATA_BLOCK: -- 0x1B70..0x1B7F -- */
    Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Chrs, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1B80..0x1B8F -- */
    Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym, Elym,
/* DATA_BLOCK: -- 0x1B90..0x1B9F -- */
    Elym, Elym, Elym, Elym, Elym, Elym, Elym, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1BA0..0x1BAF -- */
    Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah,
/* DATA_BLOCK: -- 0x1BB0..0x1BBF -- */
    Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1BC0..0x1BCF -- */
    Zzzz, Zzzz, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah, Brah,
/* DATA_BLOCK: -- 0x1BD0..0x1BDF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Brah,
/* DATA_BLOCK: -- 0x1BE0..0x1BEF -- */
    Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi, Kthi,
/* DATA_BLOCK: -- 0x1BF0..0x1BFF -- */
    Kthi, Kthi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Kthi, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1C00..0x1C0F -- */
    Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora,
/* DATA_BLOCK: -- 0x1C10..0x1C1F -- */
    Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1C20..0x1C2F -- */
    Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Sora, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1C30..0x1C3F -- */
    Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm,
/* DATA_BLOCK: -- 0x1C40..0x1C4F -- */
    Cakm, Cakm, Cakm, Cakm, Cakm, Zzzz, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm,
/* DATA_BLOCK: -- 0x1C50..0x1C5F -- */
    Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Cakm, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1C60..0x1C6F -- */
    Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj,
/* DATA_BLOCK: -- 0x1C70..0x1C7F -- */
    Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Mahj, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1C80..0x1C8F -- */
    Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd, Shrd,
/* DATA_BLOCK: -- 0x1C90..0x1C9F -- */
    Zzzz, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh, Sinh,
/* DATA_BLOCK: -- 0x1CA0..0x1CAF -- */
    Sinh, Sinh, Sinh, Sinh, Sinh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1CB0..0x1CBF -- */
    Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj,
/* DATA_BLOCK: -- 0x1CC0..0x1CCF -- */
    Khoj, Khoj, Zzzz, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj,
/* DATA_BLOCK: -- 0x1CD0..0x1CDF -- */
    Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Khoj, Zzzz,
/* DATA_BLOCK: -- 0x1CE0..0x1CEF -- */
    Mult, Mult, Mult, Mult, Mult, Mult, Mult, Zzzz, Mult, Zzzz, Mult, Mult, Mult, Mult, Zzzz, Mult,
/* DATA_BLOCK: -- 0x1CF0..0x1CFF -- */
    Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Zzzz, Mult,
/* DATA_BLOCK: -- 0x1D00..0x1D0F -- */
    Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Mult, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1D10..0x1D1F -- */
    Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind,
/* DATA_BLOCK: -- 0x1D20..0x1D2F -- */
    Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1D30..0x1D3F -- */
    Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Sind, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1D40..0x1D4F -- */
    Gran, Gran, Gran, Gran, Zzzz, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Zzzz, Zzzz, Gran,
/* DATA_BLOCK: -- 0x1D50..0x1D5F -- */
    Gran, Zzzz, Zzzz, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran,
/* DATA_BLOCK: -- 0x1D60..0x1D6F -- */
    Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Zzzz, Gran, Gran, Gran, Gran, Gran, Gran,
/* DATA_BLOCK: -- 0x1D70..0x1D7F -- */
    Gran, Zzzz, Gran, Gran, Zzzz, Gran, Gran, Gran, Gran, Gran, Zzzz, Zinh, Gran, Gran, Gran, Gran,
/* DATA_BLOCK: -- 0x1D80..0x1D8F -- */
    Gran, Gran, Gran, Gran, Gran, Zzzz, Zzzz, Gran, Gran, Zzzz, Zzzz, Gran, Gran, Gran, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1D90..0x1D9F -- */
    Gran, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Gran, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Gran, Gran, Gran,
/* DATA_BLOCK: -- 0x1DA0..0x1DAF -- */
    Gran, Gran, Gran, Gran, Zzzz, Zzzz, Gran, Gran, Gran, Gran, Gran, Gran, Gran, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1DB0..0x1DBF -- */
    Gran, Gran, Gran, Gran, Gran, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1DC0..0x1DCF -- */
    Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa,
/* DATA_BLOCK: -- 0x1DD0..0x1DDF -- */
    Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Newa, Zzzz, Newa, Newa, Newa,
/* DATA_BLOCK: -- 0x1DE0..0x1DEF -- */
    Newa, Newa, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1DF0..0x1DFF -- */
    Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh,
/* DATA_BLOCK: -- 0x1E00..0x1E0F -- */
    Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E10..0x1E1F -- */
    Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Tirh, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E20..0x1E2F -- */
    Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd,
/* DATA_BLOCK: -- 0x1E30..0x1E3F -- */
    Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Zzzz, Zzzz, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd,
/* DATA_BLOCK: -- 0x1E40..0x1E4F -- */
    Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Sidd, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E50..0x1E5F -- */
    Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi,
/* DATA_BLOCK: -- 0x1E60..0x1E6F -- */
    Modi, Modi, Modi, Modi, Modi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E70..0x1E7F -- */
    Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Modi, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E80..0x1E8F -- */
    Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Mong, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1E90..0x1E9F -- */
    Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr,
/* DATA_BLOCK: -- 0x1EA0..0x1EAF -- */
    Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1EB0..0x1EBF -- */
    Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Takr, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1EC0..0x1ECF -- */
    Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom,
/* DATA_BLOCK: -- 0x1ED0..0x1EDF -- */
    Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Zzzz, Zzzz, Ahom, Ahom, Ahom,
/* DATA_BLOCK: -- 0x1EE0..0x1EEF -- */
    Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Ahom, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1EF0..0x1EFF -- */
    Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr,
/* DATA_BLOCK: -- 0x1F00..0x1F0F -- */
    Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Dogr, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1F10..0x1F1F -- */
    Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara, Wara,
/* DATA_BLOCK: -- 0x1F20..0x1F2F -- */
    Wara, Wara, Wara, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Wara,
/* DATA_BLOCK: -- 0x1F30..0x1F3F -- */
    Diak, Diak, Diak, Diak, Diak, Diak, Diak, Zzzz, Zzzz, Diak, Zzzz, Zzzz, Diak, Diak, Diak, Diak,
/* DATA_BLOCK: -- 0x1F40..0x1F4F -- */
    Diak, Diak, Diak, Diak, Zzzz, Diak, Diak, Zzzz, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak,
/* DATA_BLOCK: -- 0x1F50..0x1F5F -- */
    Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak,
/* DATA_BLOCK: -- 0x1F60..0x1F6F -- */
    Diak, Diak, Diak, Diak, Diak, Diak, Zzzz, Diak, Diak, Zzzz, Zzzz, Diak, Diak, Diak, Diak, Diak,
/* DATA_BLOCK: -- 0x1F70..0x1F7F -- */
    Diak, Diak, Diak, Diak, Diak, Diak, Diak, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1F80..0x1F8F -- */
    Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Diak, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1F90..0x1F9F -- */
    Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Zzzz, Zzzz, Nand, Nand, Nand, Nand, Nand, Nand,
/* DATA_BLOCK: -- 0x1FA0..0x1FAF -- */
    Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand, Nand,
/* DATA_BLOCK: -- 0x1FB0..0x1FBF -- */
    Nand, Nand, Nand, Nand, Nand, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1FC0..0x1FCF -- */
    Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb,
/* DATA_BLOCK: -- 0x1FD0..0x1FDF -- */
    Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zanb, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x1FE0..0x1FEF -- */
    Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo, Soyo,
/* DATA_BLOCK: -- 0x1FF0..0x1FFF -- */
    Soyo, Soyo, Soyo, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2000..0x200F -- */
    Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc,
/* DATA_BLOCK: -- 0x2010..0x201F -- */
    Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Pauc, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2020..0x202F -- */
    Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Zzzz, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks,
/* DATA_BLOCK: -- 0x2030..0x203F -- */
    Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks,
/* DATA_BLOCK: -- 0x2040..0x204F -- */
    Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Zzzz, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks,
/* DATA_BLOCK: -- 0x2050..0x205F -- */
    Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2060..0x206F -- */
    Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Bhks, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2070..0x207F -- */
    Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc,
/* DATA_BLOCK: -- 0x2080..0x208F -- */
    Zzzz, Zzzz, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc,
/* DATA_BLOCK: -- 0x2090..0x209F -- */
    Marc, Marc, Marc, Marc, Marc, Marc, Marc, Marc, Zzzz, Marc, Marc, Marc, Marc, Marc, Marc, Marc,
/* DATA_BLOCK: -- 0x20A0..0x20AF -- */
    Marc, Marc, Marc, Marc, Marc, Marc, Marc, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x20B0..0x20BF -- */
    Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Zzzz, Gonm, Gonm, Zzzz, Gonm, Gonm, Gonm, Gonm, Gonm,
/* DATA_BLOCK: -- 0x20C0..0x20CF -- */
    Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm,
/* DATA_BLOCK: -- 0x20D0..0x20DF -- */
    Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Zzzz, Zzzz, Zzzz, Gonm, Zzzz, Gonm, Gonm, Zzzz, Gonm,
/* DATA_BLOCK: -- 0x20E0..0x20EF -- */
    Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x20F0..0x20FF -- */
    Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Gonm, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2100..0x210F -- */
    Gong, Gong, Gong, Gong, Gong, Gong, Zzzz, Gong, Gong, Zzzz, Gong, Gong, Gong, Gong, Gong, Gong,
/* DATA_BLOCK: -- 0x2110..0x211F -- */
    Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong,
/* DATA_BLOCK: -- 0x2120..0x212F -- */
    Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Zzzz,
/* DATA_BLOCK: -- 0x2130..0x213F -- */
    Gong, Gong, Zzzz, Gong, Gong, Gong, Gong, Gong, Gong, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2140..0x214F -- */
    Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Gong, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2150..0x215F -- */
    Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka,
/* DATA_BLOCK: -- 0x2160..0x216F -- */
    Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Maka, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2170..0x217F -- */
    Lisu, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2180..0x218F -- */
    Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml, Taml,
/* DATA_BLOCK: -- 0x2190..0x219F -- */
    Taml, Taml, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Taml,
/* DATA_BLOCK: -- 0x21A0..0x21AF -- */
    Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux,
/* DATA_BLOCK: -- 0x21B0..0x21BF -- */
    Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x21C0..0x21CF -- */
    Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Xsux, Zzzz,
/* DATA_BLOCK: -- 0x21D0..0x21DF -- */
    Xsux, Xsux, Xsux, Xsux, Xsux, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x21E0..0x21EF -- */
    Xsux, Xsux, Xsux, Xsux, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x21F0..0x21FF -- */
    Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp,
/* DATA_BLOCK: -- 0x2200..0x220F -- */
    Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Zzzz,
/* DATA_BLOCK: -- 0x2210..0x221F -- */
    Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Egyp, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2220..0x222F -- */
    Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw,
/* DATA_BLOCK: -- 0x2230..0x223F -- */
    Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Hluw, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2240..0x224F -- */
    Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Bamu, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2250..0x225F -- */
    Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo,
/* DATA_BLOCK: -- 0x2260..0x226F -- */
    Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Zzzz,
/* DATA_BLOCK: -- 0x2270..0x227F -- */
    Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Mroo, Zzzz, Zzzz, Zzzz, Zzzz, Mroo, Mroo,
/* DATA_BLOCK: -- 0x2280..0x228F -- */
    Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass,
/* DATA_BLOCK: -- 0x2290..0x229F -- */
    Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Bass, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x22A0..0x22AF -- */
    Bass, Bass, Bass, Bass, Bass, Bass, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x22B0..0x22BF -- */
    Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng,
/* DATA_BLOCK: -- 0x22C0..0x22CF -- */
    Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x22D0..0x22DF -- */
    Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Zzzz, Hmng, Hmng, Hmng, Hmng, Hmng,
/* DATA_BLOCK: -- 0x22E0..0x22EF -- */
    Hmng, Hmng, Zzzz, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng,
/* DATA_BLOCK: -- 0x22F0..0x22FF -- */
    Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Hmng, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Hmng, Hmng, Hmng,
/* DATA_BLOCK: -- 0x2300..0x230F -- */
    Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf,
/* DATA_BLOCK: -- 0x2310..0x231F -- */
    Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Medf, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2320..0x232F -- */
    Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd,
/* DATA_BLOCK: -- 0x2330..0x233F -- */
    Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Zzzz, Zzzz, Zzzz, Zzzz, Plrd,
/* DATA_BLOCK: -- 0x2340..0x234F -- */
    Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Plrd, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Plrd,
/* DATA_BLOCK: -- 0x2350..0x235F -- */
    Tang, Nshu, Zyyy, Zyyy, Kits, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2360..0x236F -- */
    Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2370..0x237F -- */
    Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang,
/* DATA_BLOCK: -- 0x2380..0x238F -- */
    Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2390..0x239F -- */
    Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits, Kits,
/* DATA_BLOCK: -- 0x23A0..0x23AF -- */
    Kits, Kits, Kits, Kits, Kits, Kits, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x23B0..0x23BF -- */
    Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Tang, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x23C0..0x23CF -- */
    Kana, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira,
/* DATA_BLOCK: -- 0x23D0..0x23DF -- */
    Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Hira, Zzzz,
/* DATA_BLOCK: -- 0x23E0..0x23EF -- */
    Hira, Hira, Hira, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x23F0..0x23FF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Kana, Kana, Kana, Kana, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2400..0x240F -- */
    Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu,
/* DATA_BLOCK: -- 0x2410..0x241F -- */
    Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Nshu, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2420..0x242F -- */
    Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl,
/* DATA_BLOCK: -- 0x2430..0x243F -- */
    Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2440..0x244F -- */
    Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2450..0x245F -- */
    Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2460..0x246F -- */
    Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Dupl, Zzzz, Zzzz, Dupl, Dupl, Dupl, Dupl,
/* DATA_BLOCK: -- 0x2470..0x247F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2480..0x248F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2490..0x249F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zinh, Zinh, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x24A0..0x24AF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zinh, Zinh, Zinh, Zinh,
/* DATA_BLOCK: -- 0x24B0..0x24BF -- */
    Zinh, Zinh, Zinh, Zyyy, Zyyy, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zinh, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x24C0..0x24CF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zinh, Zinh, Zinh, Zinh, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x24D0..0x24DF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x24E0..0x24EF -- */
    Grek, Grek, Grek, Grek, Grek, Grek, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x24F0..0x24FF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2500..0x250F -- */
    Zzzz, Zzzz, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2510..0x251F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2520..0x252F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2530..0x253F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2540..0x254F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2550..0x255F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz,
/* DATA_BLOCK: -- 0x2560..0x256F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2570..0x257F -- */
    Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2580..0x258F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x2590..0x259F -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x25A0..0x25AF -- */
    Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw,
/* DATA_BLOCK: -- 0x25B0..0x25BF -- */
    Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x25C0..0x25CF -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw,
/* DATA_BLOCK: -- 0x25D0..0x25DF -- */
    Zzzz, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw, Sgnw,
/* DATA_BLOCK: -- 0x25E0..0x25EF -- */
    Glag, Glag, Glag, Glag, Glag, Glag, Glag, Zzzz, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag,
/* DATA_BLOCK: -- 0x25F0..0x25FF -- */
    Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Glag, Zzzz, Zzzz, Glag, Glag, Glag, Glag, Glag,
/* DATA_BLOCK: -- 0x2600..0x260F -- */
    Glag, Glag, Zzzz, Glag, Glag, Zzzz, Glag, Glag, Glag, Glag, Glag, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2610..0x261F -- */
    Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp,
/* DATA_BLOCK: -- 0x2620..0x262F -- */
    Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2630..0x263F -- */
    Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2640..0x264F -- */
    Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Hmnp, Zzzz, Zzzz, Zzzz, Zzzz, Hmnp, Hmnp,
/* DATA_BLOCK: -- 0x2650..0x265F -- */
    Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho,
/* DATA_BLOCK: -- 0x2660..0x266F -- */
    Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Wcho, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Wcho,
/* DATA_BLOCK: -- 0x2670..0x267F -- */
    Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend,
/* DATA_BLOCK: -- 0x2680..0x268F -- */
    Mend, Mend, Mend, Mend, Mend, Zzzz, Zzzz, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend, Mend,
/* DATA_BLOCK: -- 0x2690..0x269F -- */
    Mend, Mend, Mend, Mend, Mend, Mend, Mend, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x26A0..0x26AF -- */
    Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm,
/* DATA_BLOCK: -- 0x26B0..0x26BF -- */
    Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x26C0..0x26CF -- */
    Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Adlm, Zzzz, Zzzz, Zzzz, Zzzz, Adlm, Adlm,
/* DATA_BLOCK: -- 0x26D0..0x26DF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x26E0..0x26EF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x26F0..0x26FF -- */
    Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2700..0x270F -- */
    Zzzz, Arab, Arab, Zzzz, Arab, Zzzz, Zzzz, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2710..0x271F -- */
    Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Zzzz, Arab, Zzzz, Arab, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2720..0x272F -- */
    Zzzz, Zzzz, Arab, Zzzz, Zzzz, Zzzz, Zzzz, Arab, Zzzz, Arab, Zzzz, Arab, Zzzz, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2730..0x273F -- */
    Zzzz, Arab, Arab, Zzzz, Arab, Zzzz, Zzzz, Arab, Zzzz, Arab, Zzzz, Arab, Zzzz, Arab, Zzzz, Arab,
/* DATA_BLOCK: -- 0x2740..0x274F -- */
    Zzzz, Arab, Arab, Zzzz, Arab, Zzzz, Zzzz, Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2750..0x275F -- */
    Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Zzzz, Arab, Zzzz,
/* DATA_BLOCK: -- 0x2760..0x276F -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2770..0x277F -- */
    Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Arab, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2780..0x278F -- */
    Zzzz, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab, Zzzz, Arab, Arab, Arab, Arab, Arab,
/* DATA_BLOCK: -- 0x2790..0x279F -- */
    Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x27A0..0x27AF -- */
    Hira, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x27B0..0x27BF -- */
    Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x27C0..0x27CF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x27D0..0x27DF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x27E0..0x27EF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zyyy, Zyyy, Zyyy,
/* DATA_BLOCK: -- 0x27F0..0x27FF -- */
    Zyyy, Zyyy, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zyyy, Zyyy, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2800..0x280F -- */
    Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2810..0x281F -- */
    Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2820..0x282F -- */
    Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Hani, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz,
/* DATA_BLOCK: -- 0x2830..0x283F -- */
    Zzzz, Zyyy, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz, Zzzz
};

static const SBUInt16 MainScriptIndexes[3935] = {
/* INDEX_BLOCK: -- 0x0000..0x003F -- */
    0x0000, 0x0000, 0x0000, 0x0000, 0x0010, 0x0020, 0x0010, 0x0020, 0x0000, 0x0000, 0x0030, 0x0030,
    0x0040, 0x0050, 0x0040, 0x0050, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040,
    0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040,
    0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0060, 0x0000, 0x0000, 0x0070, 0x0000,
    0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0090, 0x00A0, 0x00B0, 0x00C0, 0x00B0,
    0x00B0, 0x00B0, 0x00D0, 0x00B0,
/* INDEX_BLOCK: -- 0x0040..0x007F -- */
    0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00F0, 0x00E0, 0x00E0, 0x00E0,
    0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x0100, 0x0110, 0x0120, 0x0110, 0x0110,
    0x0130, 0x0140, 0x0150, 0x0150, 0x0160, 0x0150, 0x0170, 0x0180, 0x0190, 0x01A0, 0x01B0, 0x01B0,
    0x01C0, 0x01D0, 0x01B0, 0x01E0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01F0, 0x01B0, 0x01B0,
    0x0200, 0x0210, 0x0210, 0x0210, 0x0220, 0x01B0, 0x01B0, 0x01B0, 0x0230, 0x0230, 0x0230, 0x0240,
    0x0250, 0x0250, 0x0250, 0x0260,
/* INDEX_BLOCK: -- 0x0080..0x00BF -- */
    0x0270, 0x0270, 0x0280, 0x0290, 0x02A0, 0x02B0, 0x02C0, 0x02D0, 0x02D0, 0x02D0, 0x01B0, 0x02E0,
    0x02F0, 0x0300, 0x0310, 0x01B0, 0x0320, 0x0320, 0x0320, 0x0320, 0x0320, 0x0330, 0x0340, 0x0320,
    0x0350, 0x0360, 0x0370, 0x0380, 0x0390, 0x03A0, 0x03B0, 0x03C0, 0x03D0, 0x03E0, 0x03F0, 0x0400,
    0x0410, 0x0420, 0x0430, 0x0440, 0x0450, 0x0460, 0x0470, 0x0480, 0x0490, 0x04A0, 0x04B0, 0x04C0,
    0x04D0, 0x04E0, 0x04F0, 0x0500, 0x0510, 0x0520, 0x0530, 0x0540, 0x0550, 0x0560, 0x0570, 0x0580,
    0x0590, 0x05A0, 0x05B0, 0x05C0,
/* INDEX_BLOCK: -- 0x00C0..0x00FF -- */
    0x05D0, 0x05E0, 0x05F0, 0x0600, 0x0610, 0x0620, 0x0630, 0x0640, 0x0650, 0x0660, 0x0670, 0x0680,
    0x0690, 0x06A0, 0x06B0, 0x06C0, 0x06D0, 0x06E0, 0x06F0, 0x06F0, 0x0700, 0x0710, 0x0720, 0x06F0,
    0x0730, 0x0740, 0x0750, 0x0760, 0x0770, 0x0780, 0x0790, 0x07A0, 0x07B0, 0x07C0, 0x07C0, 0x07D0,
    0x07C0, 0x07E0, 0x02D0, 0x02D0, 0x07F0, 0x0800, 0x0810, 0x0820, 0x0830, 0x0840, 0x02D0, 0x02D0,
    0x0850, 0x0850, 0x0850, 0x0850, 0x0860, 0x0850, 0x0870, 0x0880, 0x0850, 0x0860, 0x0850, 0x0890,
    0x0890, 0x08A0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0100..0x013F -- */
    0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08B0, 0x08C0, 0x08C0,
    0x08D0, 0x08C0, 0x08C0, 0x08E0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x0900, 0x0900, 0x0900, 0x0900,
    0x0910, 0x0920, 0x0900, 0x0900, 0x0910, 0x0900, 0x0900, 0x0930, 0x0940, 0x0950, 0x0900, 0x0900,
    0x0900, 0x0940, 0x0900, 0x0900, 0x0900, 0x0960, 0x0900, 0x0970, 0x0900, 0x0980, 0x0990, 0x0990,
    0x0990, 0x0990, 0x0990, 0x09A0,
/* INDEX_BLOCK: -- 0x0140..0x017F -- */
    0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0,
    0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0,
    0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09B0,
    0x09B0, 0x09B0, 0x09B0, 0x09B0, 0x09C0, 0x09D0, 0x09E0, 0x09E0, 0x09E0, 0x09E0, 0x09F0, 0x0A00,
    0x0A10, 0x0A20, 0x0A30, 0x0A40, 0x0A50, 0x0A60, 0x0A70, 0x0A80, 0x0A90, 0x0A90, 0x0A90, 0x0A90,
    0x0A90, 0x0AA0, 0x0AB0, 0x0AB0,
/* INDEX_BLOCK: -- 0x0180..0x01BF -- */
    0x0AC0, 0x0AD0, 0x0AE0, 0x0AE0, 0x0AE0, 0x0AE0, 0x0AE0, 0x0AF0, 0x0AE0, 0x0AE0, 0x0B00, 0x09B0,
    0x09B0, 0x09B0, 0x09B0, 0x0B10, 0x0B20, 0x0B30, 0x0B40, 0x0B40, 0x0B50, 0x0B60, 0x0B70, 0x0B80,
    0x0B90, 0x0B90, 0x0BA0, 0x0B90, 0x0BB0, 0x0BC0, 0x0A90, 0x0A90, 0x0BD0, 0x0BE0, 0x0BF0, 0x0BF0,
    0x0BF0, 0x0C00, 0x0BF0, 0x0C10, 0x0C20, 0x0C20, 0x0C30, 0x0080, 0x0C40, 0x02D0, 0x02D0, 0x02D0,
    0x0C50, 0x0C50, 0x0C50, 0x0C50, 0x0C60, 0x0C50, 0x0C50, 0x0C70, 0x0C80, 0x0C80, 0x0C80, 0x0C80,
    0x0C90, 0x0C90, 0x0C90, 0x0CA0,
/* INDEX_BLOCK: -- 0x01C0..0x01FF -- */
    0x0CB0, 0x0CB0, 0x0CB0, 0x0CC0, 0x0CD0, 0x0CE0, 0x0CE0, 0x0CE0, 0x0CF0, 0x08C0, 0x08C0, 0x0D00,
    0x0D10, 0x0D20, 0x0D30, 0x0D40, 0x0040, 0x0040, 0x0D50, 0x0040, 0x0040, 0x0D60, 0x0D70, 0x0D80,
    0x0040, 0x0040, 0x0040, 0x0D90, 0x0080, 0x0080, 0x0080, 0x0DA0, 0x0040, 0x0040, 0x0040, 0x0040,
    0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040,
    0x00B0, 0x0DB0, 0x00B0, 0x00B0, 0x0DB0, 0x0DC0, 0x00B0, 0x0DD0, 0x00B0, 0x00B0, 0x00B0, 0x0DE0,
    0x0DE0, 0x0DF0, 0x00B0, 0x0E00,
/* INDEX_BLOCK: -- 0x0200..0x023F -- */
    0x0E10, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0E20, 0x0E30, 0x0E40, 0x0E50, 0x0000, 0x0000,
    0x02D0, 0x0080, 0x0080, 0x0C40, 0x0000, 0x0000, 0x0E60, 0x0E70, 0x0E80, 0x0000, 0x0040, 0x0040,
    0x0E90, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x0240..0x027F -- */
    0x0000, 0x0000, 0x0EA0, 0x02D0, 0x0EB0, 0x02D0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x0280..0x02BF -- */
    0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0,
    0x0EC0, 0x0EC0, 0x0EC0, 0x0EC0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0ED0, 0x0000, 0x0EE0, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x02C0..0x02FF -- */
    0x0EF0, 0x0EF0, 0x0F00, 0x0EF0, 0x0EF0, 0x0F00, 0x0040, 0x0040, 0x0F10, 0x0F10, 0x0F10, 0x0F10,
    0x0F10, 0x0F10, 0x0F10, 0x0F20, 0x08C0, 0x08C0, 0x08D0, 0x0F30, 0x0F30, 0x0F30, 0x0F40, 0x0F50,
    0x0900, 0x0F60, 0x0F70, 0x0F70, 0x0F70, 0x0F70, 0x00E0, 0x00E0, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0F80, 0x02D0, 0x02D0, 0x0F90, 0x0FA0, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0FB0,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0FC0, 0x02D0, 0x0FD0,
/* INDEX_BLOCK: -- 0x0300..0x033F -- */
    0x0FE0, 0x0000, 0x0FF0, 0x1000, 0x1010, 0x1020, 0x1020, 0x1020, 0x1020, 0x1030, 0x1040, 0x1050,
    0x1050, 0x1050, 0x1050, 0x1060, 0x1070, 0x1080, 0x1080, 0x1090, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x10A0, 0x0000, 0x1080, 0x1080, 0x0000, 0x0000, 0x10B0, 0x1050, 0x08F0, 0x10A0, 0x0000, 0x0000,
    0x0000, 0x0000, 0x08F0, 0x10C0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x1050, 0x1050, 0x10D0,
    0x1050, 0x1050, 0x1050, 0x1050, 0x1050, 0x10E0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x0340..0x037F -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x0380..0x03BF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0000, 0x0000, 0x0000, 0x0000, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x03C0..0x03FF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x10F0,
/* INDEX_BLOCK: -- 0x0400..0x043F -- */
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100,
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100,
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100,
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100,
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100,
    0x1100, 0x1100, 0x1100, 0x1100,
/* INDEX_BLOCK: -- 0x0440..0x047F -- */
    0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1100, 0x1110, 0x1100, 0x1100, 0x1100,
    0x1120, 0x1130, 0x1130, 0x1130, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140,
    0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1140, 0x1150, 0x02D0,
    0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x00E0, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1170,
    0x0000, 0x0000, 0x1180, 0x0040, 0x0040, 0x0040, 0x0040, 0x0040, 0x1190, 0x0040, 0x0040, 0x0040,
    0x11A0, 0x02D0, 0x02D0, 0x11B0,
/* INDEX_BLOCK: -- 0x0480..0x04BF -- */
    0x11C0, 0x11C0, 0x11D0, 0x11E0, 0x11F0, 0x11F0, 0x11F0, 0x1200, 0x1210, 0x1210, 0x1210, 0x1210,
    0x1220, 0x1230, 0x0320, 0x0320, 0x1240, 0x1240, 0x1250, 0x1260, 0x1260, 0x1270, 0x08F0, 0x1280,
    0x1290, 0x1290, 0x1290, 0x1290, 0x12A0, 0x12B0, 0x08B0, 0x12C0, 0x12D0, 0x12D0, 0x12D0, 0x12E0,
    0x12F0, 0x1300, 0x08B0, 0x08B0, 0x1310, 0x1310, 0x1310, 0x1310, 0x1320, 0x1330, 0x1340, 0x1350,
    0x1360, 0x1370, 0x0F70, 0x0040, 0x0040, 0x1380, 0x1390, 0x0990, 0x0990, 0x0990, 0x0990, 0x0990,
    0x1340, 0x1340, 0x13A0, 0x13B0,
/* INDEX_BLOCK: -- 0x04C0..0x04FF -- */
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0,
/* INDEX_BLOCK: -- 0x0500..0x053F -- */
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0,
    0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x08F0, 0x13C0, 0x08F0,
    0x13D0, 0x08F0, 0x08F0, 0x13E0,
/* INDEX_BLOCK: -- 0x0540..0x057F -- */
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0580..0x05BF -- */
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x13F0, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x1400, 0x02D0, 0x02D0,
    0x1410, 0x1420, 0x0150, 0x1430, 0x1440, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0,
    0x1450, 0x0300, 0x01B0, 0x01B0,
/* INDEX_BLOCK: -- 0x05C0..0x05FF -- */
    0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0,
    0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x1460, 0x02D0, 0x01B0, 0x01B0, 0x01B0,
    0x01B0, 0x1470, 0x01B0, 0x01B0, 0x02F0, 0x02D0, 0x02D0, 0x1480, 0x0080, 0x11E0, 0x1490, 0x0000,
    0x0000, 0x14A0, 0x14B0, 0x02E0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x01B0, 0x14C0,
    0x14D0, 0x0000, 0x0010, 0x0020, 0x0010, 0x0020, 0x14E0, 0x1040, 0x1050, 0x14F0, 0x08F0, 0x10A0,
    0x1500, 0x1510, 0x1520, 0x1530,
/* INDEX_BLOCK: -- 0x0600..0x063F -- */
    0x1540, 0x1550, 0x1560, 0x1570, 0x1580, 0x1580, 0x02D0, 0x02D0, 0x1550, 0x1550, 0x1550, 0x1550,
    0x1550, 0x1550, 0x1550, 0x1590, 0x15A0, 0x0000, 0x0000, 0x15B0, 0x00B0, 0x00B0, 0x00B0, 0x00B0,
    0x15C0, 0x15D0, 0x15E0, 0x02D0, 0x02D0, 0x0000, 0x0000, 0x15F0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x1600, 0x1610, 0x1620, 0x1620, 0x1620, 0x1630, 0x1640, 0x0FD0,
    0x1650, 0x1650, 0x1660, 0x1670, 0x1680, 0x1690, 0x1690, 0x16A0, 0x16B0, 0x16C0, 0x16D0, 0x16D0,
    0x16E0, 0x16F0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0640..0x067F -- */
    0x1700, 0x1700, 0x1700, 0x1700, 0x1700, 0x1710, 0x1710, 0x1710, 0x1720, 0x1730, 0x1740, 0x1750,
    0x1750, 0x1760, 0x1750, 0x1770, 0x1780, 0x1780, 0x1790, 0x17A0, 0x17A0, 0x17A0, 0x17B0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x17C0, 0x17C0, 0x17C0, 0x17C0,
    0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0, 0x17C0,
    0x17C0, 0x17C0, 0x17C0, 0x17D0, 0x17C0, 0x17E0, 0x17F0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0680..0x06BF -- */
    0x1800, 0x1810, 0x1810, 0x1820, 0x1830, 0x1840, 0x1850, 0x1850, 0x1860, 0x1870, 0x1880, 0x02D0,
    0x02D0, 0x02D0, 0x1890, 0x18A0, 0x18B0, 0x18C0, 0x18D0, 0x18E0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x18F0, 0x18F0, 0x1900, 0x1910, 0x1900, 0x1920, 0x1900, 0x1900, 0x1930, 0x1940, 0x1950, 0x1960,
    0x1970, 0x1970, 0x1980, 0x1980, 0x1990, 0x1990, 0x02D0, 0x02D0, 0x19A0, 0x19A0, 0x19B0, 0x19C0,
    0x19D0, 0x19D0, 0x19D0, 0x19E0, 0x19F0, 0x1A00, 0x1A10, 0x1A20, 0x1A30, 0x1A40, 0x1A50, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x06C0..0x06FF -- */
    0x1A60, 0x1A60, 0x1A60, 0x1A60, 0x1A70, 0x02D0, 0x02D0, 0x02D0, 0x1A80, 0x1A80, 0x1A80, 0x1A90,
    0x1A80, 0x1A80, 0x1A80, 0x1AA0, 0x1AB0, 0x1AB0, 0x1AC0, 0x1AD0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x01B0, 0x1AE0, 0x1AF0, 0x1AF0, 0x1B00, 0x1B10, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x1B20, 0x1B20, 0x1B30, 0x1B40, 0x1B40, 0x1B50, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x1B60,
    0x1B70, 0x02D0, 0x1B80, 0x1B90,
/* INDEX_BLOCK: -- 0x0700..0x073F -- */
    0x1BA0, 0x1BA0, 0x1BA0, 0x1BA0, 0x1BB0, 0x1BC0, 0x1BA0, 0x1BD0, 0x1BE0, 0x1BE0, 0x1BE0, 0x1BE0,
    0x1BF0, 0x1C00, 0x1C10, 0x1C20, 0x1C30, 0x1C30, 0x1C30, 0x1C40, 0x1C50, 0x1C60, 0x1C60, 0x1C70,
    0x1C80, 0x1C80, 0x1C80, 0x1C80, 0x1C80, 0x1C80, 0x1C90, 0x1CA0, 0x1CB0, 0x1CC0, 0x1CB0, 0x1CD0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x1CE0, 0x1CF0, 0x1D00, 0x1D10, 0x1D10, 0x1D10, 0x1D20, 0x1D30,
    0x1D40, 0x1D50, 0x1D60, 0x1D70, 0x1D80, 0x1D90, 0x1DA0, 0x1DB0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0740..0x077F -- */
    0x1DC0, 0x1DC0, 0x1DC0, 0x1DC0, 0x1DC0, 0x1DD0, 0x1DE0, 0x02D0, 0x1DF0, 0x1DF0, 0x1DF0, 0x1DF0,
    0x1E00, 0x1E10, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x1E20, 0x1E20, 0x1E20, 0x1E30, 0x1E20, 0x1E40, 0x02D0, 0x02D0, 0x1E50, 0x1E50, 0x1E50, 0x1E50,
    0x1E60, 0x1E70, 0x1E80, 0x02D0, 0x1E90, 0x1E90, 0x1E90, 0x1EA0, 0x1EB0, 0x02D0, 0x02D0, 0x02D0,
    0x1EC0, 0x1ED0, 0x1EE0, 0x1EC0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0780..0x07BF -- */
    0x1EF0, 0x1EF0, 0x1EF0, 0x1F00, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x1F10, 0x1F10,
    0x1F10, 0x1F10, 0x1F10, 0x1F20, 0x1F30, 0x1F40, 0x1F50, 0x1F60, 0x1F70, 0x1F80, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x1F90, 0x1FA0, 0x1FA0, 0x1F90, 0x1FB0, 0x02D0, 0x1FC0, 0x1FC0, 0x1FC0, 0x1FC0,
    0x1FD0, 0x1FE0, 0x1FE0, 0x1FE0, 0x1FE0, 0x1FE0, 0x1FF0, 0x02D0, 0x2000, 0x2000, 0x2000, 0x2010,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x07C0..0x07FF -- */
    0x2020, 0x2030, 0x2030, 0x2040, 0x2050, 0x2030, 0x2060, 0x2070, 0x2070, 0x2080, 0x2090, 0x20A0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x20B0, 0x20C0, 0x20C0, 0x20D0, 0x20E0, 0x20F0, 0x2100, 0x2110,
    0x2120, 0x2130, 0x2140, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x2150, 0x2160,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x2170,
    0x2180, 0x2180, 0x2180, 0x2190,
/* INDEX_BLOCK: -- 0x0800..0x083F -- */
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0,
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0,
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0,
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0,
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21B0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0840..0x087F -- */
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21C0, 0x21D0, 0x21A0, 0x21A0, 0x21A0, 0x21A0,
    0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21A0, 0x21E0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0880..0x08BF -- */
    0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0,
    0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0,
    0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0,
    0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0,
    0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0, 0x21F0,
    0x21F0, 0x21F0, 0x21F0, 0x21F0,
/* INDEX_BLOCK: -- 0x08C0..0x08FF -- */
    0x21F0, 0x21F0, 0x2200, 0x2210, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0900..0x093F -- */
    0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220,
    0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220,
    0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220, 0x2220,
    0x2230, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0940..0x097F -- */
    0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160,
    0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160,
    0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x1160, 0x2240,
    0x2250, 0x2260, 0x2270, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x2280, 0x2290, 0x22A0,
    0x22B0, 0x22B0, 0x22B0, 0x22B0, 0x22C0, 0x22D0, 0x22E0, 0x22F0, 0x22B0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0980..0x09BF -- */
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x2300, 0x2300, 0x2300, 0x2300, 0x2300, 0x2310, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x2320, 0x2320, 0x2320, 0x2320, 0x2330, 0x2320, 0x2320, 0x2320, 0x2340, 0x2320, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x2350, 0x2360,
/* INDEX_BLOCK: -- 0x09C0..0x09FF -- */
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370,
/* INDEX_BLOCK: -- 0x0A00..0x0A3F -- */
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2380,
/* INDEX_BLOCK: -- 0x0A40..0x0A7F -- */
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370, 0x2370,
    0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390,
    0x2390, 0x2390, 0x2390, 0x2390,
/* INDEX_BLOCK: -- 0x0A80..0x0ABF -- */
    0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390, 0x2390,
    0x2390, 0x23A0, 0x02D0, 0x02D0, 0x23B0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0AC0..0x0AFF -- */
    0x23C0, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x1020,
    0x1020, 0x1020, 0x1020, 0x1020, 0x1020, 0x23D0, 0x02D0, 0x02D0, 0x02D0, 0x23E0, 0x23F0, 0x2400,
    0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400,
    0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2400, 0x2410,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0B00..0x0B3F -- */
    0x2420, 0x2420, 0x2420, 0x2420, 0x2420, 0x2420, 0x2430, 0x2440, 0x2450, 0x2460, 0x10B0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0B40..0x0B7F -- */
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x2470, 0x0000, 0x0000, 0x2480, 0x0000, 0x0000, 0x0000, 0x2490, 0x24A0,
    0x24B0, 0x0000, 0x24C0, 0x0000, 0x0000, 0x0000, 0x24D0, 0x02D0, 0x00B0, 0x00B0, 0x00B0, 0x00B0,
    0x24E0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x0000, 0x10B0,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0EA0, 0x0000, 0x24D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0B80..0x0BBF -- */
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0E20, 0x0000, 0x0000, 0x0000, 0x24F0, 0x2500, 0x2510,
    0x2520, 0x0000, 0x0000, 0x0000, 0x2530, 0x2540, 0x0000, 0x2550, 0x2560, 0x2570, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2580, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x2590, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x0BC0..0x0BFF -- */
    0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0,
    0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0,
    0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25A0,
    0x25A0, 0x25A0, 0x25A0, 0x25A0, 0x25B0, 0x25C0, 0x25D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0C00..0x0C3F -- */
    0x25E0, 0x25F0, 0x2600, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x2610, 0x2610, 0x2620, 0x2630, 0x2640, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x2650, 0x2650, 0x2650, 0x2660,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0C40..0x0C7F -- */
    0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670, 0x2670,
    0x2680, 0x2690, 0x02D0, 0x02D0, 0x26A0, 0x26A0, 0x26A0, 0x26A0, 0x26B0, 0x26C0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0C80..0x0CBF -- */
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x14D0, 0x0000, 0x0000, 0x0000, 0x26D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x14D0, 0x0000, 0x0000, 0x26E0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x26F0, 0x01B0, 0x2700, 0x2710,
    0x2720, 0x2730, 0x2740, 0x2750, 0x2760, 0x2770, 0x2780, 0x2770, 0x02D0, 0x02D0, 0x02D0, 0x1450,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0CC0..0x0CFF -- */
    0x0000, 0x0000, 0x0FD0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x10B0, 0x0E40, 0x14D0,
    0x14D0, 0x14D0, 0x0000, 0x2470, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x26E0, 0x02D0, 0x02D0, 0x02D0, 0x2790, 0x0000, 0x27A0, 0x0000, 0x0000, 0x0FD0,
    0x24D0, 0x27B0, 0x2470, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000,
/* INDEX_BLOCK: -- 0x0D00..0x0D3F -- */
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x27C0, 0x15D0, 0x15D0,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x10B0, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x24D0, 0x0FD0, 0x02D0,
/* INDEX_BLOCK: -- 0x0D40..0x0D7F -- */
    0x0FD0, 0x0000, 0x0000, 0x0000, 0x27C0, 0x11E0, 0x0000, 0x0000, 0x27C0, 0x0000, 0x26E0, 0x27B0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x27D0,
    0x0000, 0x0000, 0x0000, 0x0000, 0x27E0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x10B0, 0x26E0, 0x27F0, 0x0EA0, 0x0000, 0x24D0, 0x0EA0, 0x0F80, 0x0EA0, 0x02D0, 0x02D0,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x14A0, 0x0000, 0x0000,
    0x0EB0, 0x02D0, 0x02D0, 0x11E0,
/* INDEX_BLOCK: -- 0x0D80..0x0DBF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x13F0, 0x02D0, 0x02D0,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x0DC0..0x0DFF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x2800, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x0E00..0x0E3F -- */
    0x0F90, 0x13F0, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x0E40..0x0E7F -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x2360, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90,
/* INDEX_BLOCK: -- 0x0E80..0x0EBF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x2810, 0x02D0,
/* INDEX_BLOCK: -- 0x0EC0..0x0EFF -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x13F0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0F00..0x0F3F -- */
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x0F90,
    0x0F90, 0x0F90, 0x0F90, 0x0F90, 0x2820, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0,
/* INDEX_BLOCK: -- 0x0F40..0x0F5E -- */
    0x2830, 0x02D0, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x02D0, 0x02D0, 0x02D0, 0x02D0,
    0x02D0, 0x02D0, 0x02D0, 0x02D0, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080,
    0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080, 0x0080
};

static const SBUInt16 BranchScriptIndexes[897] = {
    0x0000, 0x0040, 0x0080, 0x00C0, 0x0100, 0x0140, 0x0180, 0x01C0, 0x0200, 0x0240, 0x0280, 0x02C0,
    0x0300, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0380, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0340, 0x0340, 0x03C0, 0x0400, 0x0440, 0x0480, 0x04C0, 0x04C0, 0x04C0, 0x04C0, 0x04C0,
    0x04C0, 0x04C0, 0x04C0, 0x04C0, 0x04C0, 0x0500, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0580, 0x05C0, 0x0600, 0x0640, 0x0680, 0x06C0, 0x0700, 0x0740, 0x0780, 0x07C0,
    0x0800, 0x0840, 0x0540, 0x0540, 0x0880, 0x08C0, 0x0540, 0x0540, 0x0540, 0x0900, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0940, 0x0980, 0x09C0, 0x09C0, 0x09C0, 0x09C0,
    0x09C0, 0x0A00, 0x0A40, 0x0A80, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0AC0, 0x0540, 0x0540, 0x0B00, 0x0540, 0x0540, 0x0540, 0x0540, 0x0B40, 0x0B80, 0x0BC0, 0x0540,
    0x0C00, 0x0540, 0x0C40, 0x0C80, 0x0CC0, 0x0D00, 0x0D40, 0x0540, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340,
    0x0340, 0x0D80, 0x0340, 0x0340, 0x0340, 0x0DC0, 0x0E00, 0x0340, 0x0340, 0x0340, 0x0340, 0x0E40,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0340, 0x0E80, 0x0540, 0x0540, 0x0540, 0x0EC0, 0x0540,
    0x0340, 0x0340, 0x0340, 0x0340, 0x0F00, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540,
    0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0540, 0x0F40
};

SB_INTERNAL SBScript LookupScript(SBCodepoint codepoint)
{
    if (codepoint <= 0x0E01EF) {
        return PrimaryScriptData[
                MainScriptIndexes[
                 BranchScriptIndexes[
                      codepoint / 0x0400
                 ] + (codepoint % 0x0400) / 0x0010
                ] + codepoint % 0x0010
               ];
    }

    return Zzzz;
}

#undef Adlm
#undef Aghb
#undef Ahom
#undef Arab
#undef Armi
#undef Armn
#undef Avst
#undef Bali
#undef Bamu
#undef Bass
#undef Batk
#undef Beng
#undef Bhks
#undef Bopo
#undef Brah
#undef Brai
#undef Bugi
#undef Buhd
#undef Cakm
#undef Cans
#undef Cari
#undef Cham
#undef Cher
#undef Chrs
#undef Copt
#undef Cprt
#undef Cyrl
#undef Deva
#undef Diak
#undef Dogr
#undef Dsrt
#undef Dupl
#undef Egyp
#undef Elba
#undef Elym
#undef Ethi
#undef Geor
#undef Glag
#undef Gong
#undef Gonm
#undef Goth
#undef Gran
#undef Grek
#undef Gujr
#undef Guru
#undef Hang
#undef Hani
#undef Hano
#undef Hatr
#undef Hebr
#undef Hira
#undef Hluw
#undef Hmng
#undef Hmnp
#undef Hung
#undef Ital
#undef Java
#undef Kali
#undef Kana
#undef Khar
#undef Khmr
#undef Khoj
#undef Kits
#undef Knda
#undef Kthi
#undef Lana
#undef Laoo
#undef Latn
#undef Lepc
#undef Limb
#undef Lina
#undef Linb
#undef Lisu
#undef Lyci
#undef Lydi
#undef Mahj
#undef Maka
#undef Mand
#undef Mani
#undef Marc
#undef Medf
#undef Mend
#undef Merc
#undef Mero
#undef Mlym
#undef Modi
#undef Mong
#undef Mroo
#undef Mtei
#undef Mult
#undef Mymr
#undef Nand
#undef Narb
#undef Nbat
#undef Newa
#undef Nkoo
#undef Nshu
#undef Ogam
#undef Olck
#undef Orkh
#undef Orya
#undef Osge
#undef Osma
#undef Palm
#undef Pauc
#undef Perm
#undef Phag
#undef Phli
#undef Phlp
#undef Phnx
#undef Plrd
#undef Prti
#undef Rjng
#undef Rohg
#undef Runr
#undef Samr
#undef Sarb
#undef Saur
#undef Sgnw
#undef Shaw
#undef Shrd
#undef Sidd
#undef Sind
#undef Sinh
#undef Sogd
#undef Sogo
#undef Sora
#undef Soyo
#undef Sund
#undef Sylo
#undef Syrc
#undef Tagb
#undef Takr
#undef Tale
#undef Talu
#undef Taml
#undef Tang
#undef Tavt
#undef Telu
#undef Tfng
#undef Tglg
#undef Thaa
#undef Thai
#undef Tibt
#undef Tirh
#undef Ugar
#undef Vaii
#undef Wara
#undef Wcho
#undef Xpeo
#undef Xsux
#undef Yezi
#undef Yiii
#undef Zanb
#undef Zinh
#undef Zyyy
#undef Zzzz
